# wise-api-client
Comprehensive API for Wise platform services including:
- Profile
- Activity tracking and management
- Quote creation and management
- Recipient
- Transfer


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.4
- Package version: 0.0.4
- Build date: 2025-04-17T13:11:20.297908150Z[Etc/UTC]
- Generator version: 7.13.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/maxploter/wise-python.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/maxploter/wise-python.git`)

Then import the package:
```python
import wise_api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import wise_api_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import wise_api_client
from wise_api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.sandbox.transferwise.tech
# See configuration.py for a list of all supported configuration parameters.
configuration = wise_api_client.Configuration(
    host = "https://api.sandbox.transferwise.tech"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: BearerAuth
configuration = wise_api_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with wise_api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = wise_api_client.ActivitiesApi(api_client)
    profile_id = 'profile_id_example' # str | ID of the user profile
    monetary_resource_type = wise_api_client.ActivityResourceType() # ActivityResourceType | Filter by resource type (optional)
    status = wise_api_client.ActivityStatus() # ActivityStatus | Filter by activity status (optional)
    since = '2013-10-20T19:20:30+01:00' # datetime | Filter activities created after this timestamp (optional)
    until = '2013-10-20T19:20:30+01:00' # datetime | Filter activities created before this timestamp (optional)
    next_cursor = 'next_cursor_example' # str | Pagination cursor for next page (optional)
    size = 10 # int | Number of results per page (optional) (default to 10)

    try:
        # List activities for a profile
        api_response = api_instance.list_activities(profile_id, monetary_resource_type=monetary_resource_type, status=status, since=since, until=until, next_cursor=next_cursor, size=size)
        print("The response of ActivitiesApi->list_activities:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ActivitiesApi->list_activities: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.sandbox.transferwise.tech*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ActivitiesApi* | [**list_activities**](docs/ActivitiesApi.md#list_activities) | **GET** /v1/profiles/{profileId}/activities | List activities for a profile
*ProfilesApi* | [**add_directors**](docs/ProfilesApi.md#add_directors) | **POST** /v1/profiles/{profileId}/directors | Add directors
*ProfilesApi* | [**check_verification_status**](docs/ProfilesApi.md#check_verification_status) | **POST** /v3/profiles/{profileId}/verification-status/bank-transfer | Check verification status
*ProfilesApi* | [**create_business_profile**](docs/ProfilesApi.md#create_business_profile) | **POST** /v2/profiles/business-profile | Create a business profile
*ProfilesApi* | [**create_personal_profile**](docs/ProfilesApi.md#create_personal_profile) | **POST** /v2/profiles/personal-profile | Create a personal profile
*ProfilesApi* | [**create_verification_document**](docs/ProfilesApi.md#create_verification_document) | **POST** /v1/profiles/{profileId}/verification-documents | Create identification document
*ProfilesApi* | [**get_profile_by_id**](docs/ProfilesApi.md#get_profile_by_id) | **GET** /v2/profiles/{profileId} | Retrieve a profile by ID
*ProfilesApi* | [**list_directors**](docs/ProfilesApi.md#list_directors) | **GET** /v1/profiles/{profileId}/directors | List directors
*ProfilesApi* | [**list_profiles**](docs/ProfilesApi.md#list_profiles) | **GET** /v2/profiles | List profiles for a user account
*ProfilesApi* | [**update_business_profile**](docs/ProfilesApi.md#update_business_profile) | **PUT** /v2/profiles/{profileId}/business-profile | Update a business profile
*ProfilesApi* | [**update_directors**](docs/ProfilesApi.md#update_directors) | **PUT** /v1/profiles/{profileId}/directors | Update directors
*ProfilesApi* | [**update_personal_profile**](docs/ProfilesApi.md#update_personal_profile) | **PUT** /v2/profiles/{profileId}/personal-profile | Update a personal profile
*QuotesApi* | [**create_authenticated_quote**](docs/QuotesApi.md#create_authenticated_quote) | **POST** /v3/profiles/{profileId}/quotes | Create an authenticated quote
*QuotesApi* | [**create_unauthenticated_quote**](docs/QuotesApi.md#create_unauthenticated_quote) | **POST** /v3/quotes | Create an unauthenticated quote
*QuotesApi* | [**get_quote_by_id**](docs/QuotesApi.md#get_quote_by_id) | **GET** /v3/profiles/{profileId}/quotes/{quoteId} | Retrieve a quote by ID
*QuotesApi* | [**update_quote**](docs/QuotesApi.md#update_quote) | **PATCH** /v3/profiles/{profileId}/quotes/{quoteId} | Update a quote
*RecipientsApi* | [**create_recipient_account**](docs/RecipientsApi.md#create_recipient_account) | **POST** /v1/accounts | Create a recipient account
*RecipientsApi* | [**create_refund_recipient_account**](docs/RecipientsApi.md#create_refund_recipient_account) | **POST** /v1/refund-accounts | Create a refund recipient account
*RecipientsApi* | [**deactivate_recipient_account**](docs/RecipientsApi.md#deactivate_recipient_account) | **DELETE** /v2/accounts/{accountId} | Deactivate a recipient account
*RecipientsApi* | [**get_account_requirements**](docs/RecipientsApi.md#get_account_requirements) | **GET** /v1/quotes/{quoteId}/account-requirements | Get account requirements for a quote
*RecipientsApi* | [**get_recipient_account_by_id**](docs/RecipientsApi.md#get_recipient_account_by_id) | **GET** /v2/accounts/{accountId} | Get recipient account by ID
*RecipientsApi* | [**list_recipient_accounts**](docs/RecipientsApi.md#list_recipient_accounts) | **GET** /v2/accounts | List recipient accounts
*TransfersApi* | [**calculate_transfer_requirements**](docs/TransfersApi.md#calculate_transfer_requirements) | **POST** /v1/transfer-requirements | Get transfer requirements
*TransfersApi* | [**cancel_transfer**](docs/TransfersApi.md#cancel_transfer) | **PUT** /v1/transfers/{transferId} | Cancel transfer
*TransfersApi* | [**create_partner_licence_transfer**](docs/TransfersApi.md#create_partner_licence_transfer) | **POST** /v1/profiles/{profileId}/partner-licence-transfers | Create partner license
*TransfersApi* | [**create_third_party_transfer**](docs/TransfersApi.md#create_third_party_transfer) | **POST** /v2/profiles/{profileId}/third-party-transfers | Create third-party transfer
*TransfersApi* | [**create_transfer**](docs/TransfersApi.md#create_transfer) | **POST** /v1/transfers | Create a standard transfer
*TransfersApi* | [**fund_transfer**](docs/TransfersApi.md#fund_transfer) | **POST** /v3/profiles/{profileId}/transfers/{transferId}/payments | Fund a transfer
*TransfersApi* | [**get_banking_partner_invoice**](docs/TransfersApi.md#get_banking_partner_invoice) | **GET** /v2/transfers/{transferId}/invoices/bankingpartner | Get banking partner invoice (v2)
*TransfersApi* | [**get_noc_document**](docs/TransfersApi.md#get_noc_document) | **GET** /v1/transfers/{transferId}/documents/noc | Get NOC document
*TransfersApi* | [**get_third_party_transfer**](docs/TransfersApi.md#get_third_party_transfer) | **GET** /v2/profiles/{profileId}/third-party-transfers/{transferId} | Get third-party transfer
*TransfersApi* | [**get_transfer_by_id**](docs/TransfersApi.md#get_transfer_by_id) | **GET** /v1/transfers/{transferId} | Get transfer by ID
*TransfersApi* | [**get_transfer_receipt**](docs/TransfersApi.md#get_transfer_receipt) | **GET** /v1/transfers/{transferId}/receipt.pdf | Get transfer receipt PDF
*TransfersApi* | [**list_transfer_payments**](docs/TransfersApi.md#list_transfer_payments) | **GET** /v1/transfers/{transferId}/payments | List transfer payments
*TransfersApi* | [**list_transfers**](docs/TransfersApi.md#list_transfers) | **GET** /v1/transfers | List transfers


## Documentation For Models

 - [AccountRequirementsInner](docs/AccountRequirementsInner.md)
 - [AccountRequirementsInnerFieldsInner](docs/AccountRequirementsInnerFieldsInner.md)
 - [AccountRequirementsInnerFieldsInnerGroupInner](docs/AccountRequirementsInnerFieldsInnerGroupInner.md)
 - [AccountRequirementsInnerFieldsInnerGroupInnerValuesAllowedInner](docs/AccountRequirementsInnerFieldsInnerGroupInnerValuesAllowedInner.md)
 - [ActivitiesResponse](docs/ActivitiesResponse.md)
 - [Activity](docs/Activity.md)
 - [ActivityResource](docs/ActivityResource.md)
 - [ActivityResourceType](docs/ActivityResourceType.md)
 - [ActivityStatus](docs/ActivityStatus.md)
 - [ActivityType](docs/ActivityType.md)
 - [Amount](docs/Amount.md)
 - [BankingPartnerInvoice](docs/BankingPartnerInvoice.md)
 - [BusinessProfile](docs/BusinessProfile.md)
 - [BusinessProfileDetails](docs/BusinessProfileDetails.md)
 - [CreateAuthenticatedQuoteRequest](docs/CreateAuthenticatedQuoteRequest.md)
 - [CreateAuthenticatedQuoteRequestPaymentMetadata](docs/CreateAuthenticatedQuoteRequestPaymentMetadata.md)
 - [CreateBusinessProfileRequest](docs/CreateBusinessProfileRequest.md)
 - [CreatePartnerLicenceTransferRequest](docs/CreatePartnerLicenceTransferRequest.md)
 - [CreatePersonalProfileRequest](docs/CreatePersonalProfileRequest.md)
 - [CreatePersonalProfileRequestAddress](docs/CreatePersonalProfileRequestAddress.md)
 - [CreatePersonalProfileRequestContactDetails](docs/CreatePersonalProfileRequestContactDetails.md)
 - [CreateRecipientRequest](docs/CreateRecipientRequest.md)
 - [CreateRecipientRequestDetails](docs/CreateRecipientRequestDetails.md)
 - [CreateRefundRecipientAccountRequest](docs/CreateRefundRecipientAccountRequest.md)
 - [CreateRefundRecipientAccountRequestName](docs/CreateRefundRecipientAccountRequestName.md)
 - [CreateStandardTransferRequest](docs/CreateStandardTransferRequest.md)
 - [CreateThirdPartyTransferRequest](docs/CreateThirdPartyTransferRequest.md)
 - [CreateUnauthenticatedQuoteRequest](docs/CreateUnauthenticatedQuoteRequest.md)
 - [CreateVerificationDocumentRequest](docs/CreateVerificationDocumentRequest.md)
 - [Director](docs/Director.md)
 - [Error](docs/Error.md)
 - [FeeConfiguration](docs/FeeConfiguration.md)
 - [FeeDetails](docs/FeeDetails.md)
 - [GetProfileById200Response](docs/GetProfileById200Response.md)
 - [ListProfiles200ResponseInner](docs/ListProfiles200ResponseInner.md)
 - [ListTransfers200ResponseInner](docs/ListTransfers200ResponseInner.md)
 - [Notice](docs/Notice.md)
 - [Originator](docs/Originator.md)
 - [OriginatorAddress](docs/OriginatorAddress.md)
 - [OriginatorName](docs/OriginatorName.md)
 - [OriginatorTransfer](docs/OriginatorTransfer.md)
 - [PaginatedRecipients](docs/PaginatedRecipients.md)
 - [PaymentOption](docs/PaymentOption.md)
 - [PaymentRequest](docs/PaymentRequest.md)
 - [PaymentResponse](docs/PaymentResponse.md)
 - [PaymentsListInner](docs/PaymentsListInner.md)
 - [PersonalProfile](docs/PersonalProfile.md)
 - [PersonalProfileDetails](docs/PersonalProfileDetails.md)
 - [PersonalProfileDetailsOccupationsInner](docs/PersonalProfileDetailsOccupationsInner.md)
 - [PriceDetails](docs/PriceDetails.md)
 - [PricingConfiguration](docs/PricingConfiguration.md)
 - [Quote](docs/Quote.md)
 - [Recipient](docs/Recipient.md)
 - [RecipientCommonFieldMap](docs/RecipientCommonFieldMap.md)
 - [RecipientDetails](docs/RecipientDetails.md)
 - [RecipientDisplayFieldsInner](docs/RecipientDisplayFieldsInner.md)
 - [RecipientName](docs/RecipientName.md)
 - [RequirementField](docs/RequirementField.md)
 - [StandardTransfer](docs/StandardTransfer.md)
 - [TotalPrice](docs/TotalPrice.md)
 - [TransferDetails](docs/TransferDetails.md)
 - [TransferRequirementsRequest](docs/TransferRequirementsRequest.md)
 - [TransferRequirementsResponseInner](docs/TransferRequirementsResponseInner.md)
 - [TransferRequirementsResponseInnerFieldsInner](docs/TransferRequirementsResponseInnerFieldsInner.md)
 - [UBO](docs/UBO.md)
 - [UpdateBusinessProfileRequest](docs/UpdateBusinessProfileRequest.md)
 - [UpdatePersonalProfileRequest](docs/UpdatePersonalProfileRequest.md)
 - [UpdateQuoteRequest](docs/UpdateQuoteRequest.md)
 - [UpdateQuoteRequestPaymentMetadata](docs/UpdateQuoteRequestPaymentMetadata.md)
 - [VerificationStatusResponse](docs/VerificationStatusResponse.md)
 - [VerificationStatusResponseRoutesInner](docs/VerificationStatusResponseRoutesInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="BearerAuth"></a>
### BearerAuth

- **Type**: Bearer authentication


## Author

maksim.ploter@gmail.com


